@@ -1,6 +1,7 @@
 #include "atlas_misc.h"
 #include <assert.h>
 #include <string.h>
+#include <ctype.h>
 
 #define AlphaX 2
 typedef struct FileNode FILENODE;
@@ -158,7 +159,7 @@ FILENODE *ReadFile(char pre)
 {
    FILE *fpin;
    FILENODE *fbase, *fn, *fp=NULL;
-   char ln[512], rout[256], auth[256], cc[256], ccflags[256];
+   char ln[512], rout[256], auth[256], cc[256], ccflags[512];
    char *pcc, *pccflags;
    int i, n, ID, alpha, beta, incX, incY;
 
@@ -1112,10 +1113,10 @@ char GetFlags(int nargs, char **args)
    }
    return(ch);
 }
-main(int nargs, char **args)
+int main(int nargs, char **args)
 {
    char pre;
    pre = GetFlags(nargs, args);
    GoToTown(pre);
-   exit(0);
+   return(0);
 }
